Bearer

Struct Bearer 

pub struct Bearer(/* private fields */);
ATT bearer ([Vol 3] Part F, Section 3.2.11).

Implementations

Source

impl Bearer

Find information encoders ([Vol 3] Part F, Section 3.4.3).

pub fn find_information_rsp( &self, start: Handle, it: impl Iterator<Item = (Handle, Uuid)>, ) -> RspResult<Rsp>

Returns an ATT_FIND_INFORMATION_RSP PDU ([Vol 3] Part F, Section 3.4.3.2).

pub fn find_by_type_value_rsp( &self, start: Handle, it: impl Iterator<Item = (Handle, Option<Handle>)>, ) -> RspResult<Rsp>

Returns an ATT_FIND_BY_TYPE_VALUE_RSP PDU ([Vol 3] Part F, Section 3.4.3.4).

Source

impl Bearer

Reading attributes encoders ([Vol 3] Part F, Section 3.4.4).

pub fn read_by_type_rsp( &self, start: Handle, it: impl ValueIter<Handle>, ) -> RspResult<Rsp>

Returns an ATT_READ_BY_TYPE_RSP PDU ([Vol 3] Part F, Section 3.4.4.2).

pub fn read_rsp(&self, v: &[u8]) -> RspResult<Rsp>

Returns an ATT_READ_RSP PDU ([Vol 3] Part F, Section 3.4.4.4).

pub fn read_blob_rsp(&self, v: &[u8]) -> RspResult<Rsp>

Returns an ATT_READ_BLOB_RSP PDU ([Vol 3] Part F, Section 3.4.4.6).

pub fn read_multiple_rsp<T>(&self, it: impl ValueIter<T>) -> RspResult<Rsp>

Returns an ATT_READ_MULTIPLE_RSP PDU ([Vol 3] Part F, Section 3.4.4.8).

pub fn read_by_group_type_rsp( &self, start: Handle, it: impl ValueIter<HandleRange>, ) -> RspResult<Rsp>

Returns an ATT_READ_BY_GROUP_TYPE_RSP PDU ([Vol 3] Part F, Section 3.4.4.10).

pub fn read_multiple_variable_rsp<T>( &self, it: impl ValueIter<T>, ) -> RspResult<Rsp>

Returns an ATT_READ_MULTIPLE_VARIABLE_RSP PDU ([Vol 3] Part F, Section 3.4.4.12).

Source

impl Bearer

Writing attributes encoders ([Vol 3] Part F, Section 3.4.5).

pub fn write_rsp(&self) -> RspResult<Rsp>

Returns an ATT_WRITE_RSP PDU ([Vol 3] Part F, Section 3.4.5.2).

Source

impl Bearer

Queued writes encoders ([Vol 3] Part F, Section 3.4.6).

pub fn prepare_write_rsp( &self, hdl: Handle, off: u16, v: &[u8], ) -> RspResult<Rsp>

Returns an ATT_PREPARE_WRITE_RSP PDU ([Vol 3] Part F, Section 3.4.6.2).

pub fn execute_write_rsp(&self) -> RspResult<Rsp>

Returns an ATT_EXECUTE_WRITE_RSP PDU ([Vol 3] Part F, Section 3.4.6.4).

Source

impl Bearer

Server initiated encoders ([Vol 3] Part F, Section 3.4.7).

pub async fn handle_value_ntf(&mut self, hdl: Handle, v: &[u8]) -> Result<()>

Sends an ATT_HANDLE_VALUE_NTF PDU ([Vol 3] Part F, Section 3.4.7.1).

pub async fn handle_value_ind(&mut self, hdl: Handle, v: &[u8]) -> Result<()>

Sends an ATT_HANDLE_VALUE_IND PDU and waits for the confirmation ([Vol 3] Part F, Section 3.4.7.2).

pub async fn multiple_handle_value_ntf( &mut self, it: impl Iterator<Item = (Handle, &[u8])> + Send, ) -> Result<()>

Sends an ATT_MULTIPLE_HANDLE_VALUE_NTF PDU ([Vol 3] Part F, Section 3.4.7.4).

Source

impl Bearer

pub fn cid(&self) -> LeCid

Returns the channel ID.

pub const fn mtu(&self) -> u16

Returns the current MTU.

pub async fn recv(&mut self) -> Result<Pdu>

Returns the next command, request, notification, or indication PDU. This method is cancel safe.

pub async fn send_rsp(&mut self, r: RspResult<Rsp>) -> Result<()>

Sends a response PDU or an ATT_ERROR_RSP if the request could not be completed ([Vol 3] Part F, Section 3.4.1.1). Command-related errors are ignored.